/**
 * popup script
 * @author GavinGong
 * @package triptain-chrome-extension-spider-zh
 */

/**
 * --------------------------------------------------------------
 * 初始化页面HTML
 * --------------------------------------------------------------
 */
chrome.storage.local.get(['user_id'], function (result) {
    if (typeof (result.user_id) === "undefined") {
        $('#login').show();
    } else {
        //显示店铺列表
        get_shop_list_html();
        $('#shop_list').show();
    }
});

/**
 * --------------------------------------------------------------
 * 事件-登录
 * --------------------------------------------------------------
 */
$("#btn_login").click(function () {
    $.get("https://www.loophot.com/open/login", {email: $("#email").val(), password: $("#password").val()},
        function (data) {
            if (data.code === '0') {
                //缓存登录状态
                chrome.storage.local.set({user_id: data.data.user_id}, function () {
                });

                //缓存当前店铺
                chrome.storage.local.set({user_shops: data.data.user_shops}, function () {
                    get_shop_list_html();
                });

                $('#login').hide();
                $('#shop_list').show();
                $('#current_user_id').val(data.data.user_id);

                //发送消息给活动标签
                sendMessage('login').then(r => 200);
            } else {
                $('#error_message').html(data.message);
            }
        });
});

/**
 * --------------------------------------------------------------
 * 事件-退出
 * --------------------------------------------------------------
 */
$('#btn_logout').click(function () {
    //删除用户ID
    chrome.storage.local.remove('user_id', function () {
    });
    //删除用户店铺列表
    chrome.storage.local.remove('user_shops', function () {
    });
    //删除当前选品店铺ID
    chrome.storage.local.remove('current_shop_id', function () {
    });
    //删除当前选品店铺细分市场
    chrome.storage.local.remove('current_shop_tags', function () {
    });

    //切换视图
    $('#shop_list').hide();
    $('#login').show();

    $('#current_user_id').val('');

    //发送消息给活动标签
    sendMessage('logout').then(r => 200);
});

/**
 * --------------------------------------------------------------
 * 事件-设置选品店铺
 * --------------------------------------------------------------
 */
$(document).on("click", '#shop_list ul li', function () {
    let shop_id = $(this).attr('shop_id');

    chrome.storage.local.get(['user_id'], function (result) {
        $.get("https://erp.loophot.com/open/shop/tags", {user_id: result.user_id, shop_id: shop_id},
            function (data) {
                if (data.code === '0') {
                    chrome.storage.local.set({current_shop_id: shop_id, current_shop_tags: data.data}, function () {
                        get_shop_list_html();

                        //发送消息给活动标签
                        sendMessage('select_shop').then(r => 200);
                    });
                } else {
                    console.log(data.message);
                }
            });
    });
});


/**
 * --------------------------------------------------------------
 * 方法 - 获取当前tab标签
 * --------------------------------------------------------------
 */
async function getCurrentTab() {
    let queryOptions = {active: true, lastFocusedWindow: true};
    let [tab] = await chrome.tabs.query(queryOptions);
    return tab;
}

/**
 * --------------------------------------------------------------
 * 方法 - 发送消息给活动标签
 * --------------------------------------------------------------
 */
const sendMessage = async (event_name) => {
    const tab = await getCurrentTab();
    await chrome.tabs.sendMessage(tab.id, {name: event_name});
};

/**
 * --------------------------------------------------------------
 * 方法 - 生成并显示店铺列表
 * --------------------------------------------------------------
 */
function get_shop_list_html() {
    chrome.storage.local.get(['user_shops'], function (result_user_shops) {
        if (typeof (result_user_shops.user_shops) === "undefined") {
            //----------------店铺列表为空
            $('#no_shops_message').show();
        } else {
            //----------------店铺列表不空
            chrome.storage.local.get(['current_shop_id'], function (result_current_shop) {
                //----------------不存在当前选品店铺
                if (typeof (result_current_shop.current_shop_id) === "undefined") {
                    let html = '';
                    for (let key in result_user_shops.user_shops) {
                        html += "<li class='list-group-item' shop_id='" + key + "'>" + result_user_shops.user_shops[key] + "</li>";
                    }

                    $('#shop_list ul').html(html);
                } else {
                    //----------------存在当前选品店铺
                    let html = '';
                    for (let key in result_user_shops.user_shops) {
                        html += "<li class='list-group-item";
                        if (result_current_shop.current_shop_id === key) {
                            html += " active";
                        }
                        html += "' shop_id='" + key + "'>" + result_user_shops.user_shops[key] + "</li>";
                    }

                    $('#shop_list ul').html(html);
                }
            });

            $('#no_shops_message').hide();
        }
    });
}